CLASS HMGQT FROM APPLICATION

// data
   DATA cClassName                                 INIT "HMGQT"

   DATA oQtObject                                  INIT NIL
   DATA bOnShutDown                                INIT NIL

// method and properties
   METHOD Quit
   METHOD Start
   METHOD RegisterResource
   METHOD UnRegisterResources

// events

ENDCLASS

/*..............................................................................
 Quit
..............................................................................*/
METHOD HMGQT:Quit()

   IF ::s_qStarted == .T.
// run bOnShutDown
      IF hb_isblock( ::bOnShutDown ) == .T.
         EVAL( ::bOnShutDown )
      ENDIF

      Self:UnRegisterResources()
      ::s_qApp:Exit()
      ::s_qApp:Quit()
   ENDIF

   hb_gcall()

RETURN Self

/*..............................................................................
 Start
 params
 -onshutdown={|| FunctionName()}
 -pluginpath=PathName

 in this way you can put plugins dll in <ExePath>\Qt\Plugins and Qt try to find here and qt.conf it's not required
 ie <ExePath>\Qt\Plugins\ImageFormats\qico4.dll
..............................................................................*/
METHOD HMGQT:Start( ... )

   LOCAL cPath, cFile, cExt, QtPluginPath
   LOCAL aParams, cArg, aField

// check if it's already started
   IF ::s_qStarted == .F.
      RETURN Self
   ENDIF

// manage parameters
   aParams := hb_aparams()
   FOR EACH cArg IN aParams
      aField := hb_regexsplit( "=", cArg, 2 )
      IF LEN( aField ) <> 2
         LOOP
      ELSE
         IF LOWER( ALLTRIM( aField[1] ) ) == "-onshutdown" .AND. hb_isblock( ALLTRIM( aField[2] ) ) == .T.
            ::bOnShutDown := ALLTRIM( aField[2] )
         ELSEIF LOWER( ALLTRIM( aField[1] ) ) == "-pluginpath" .AND. hb_direxists( ALLTRIM( aField[2] ) ) == .T.
            QtPluginPath := ALLTRIM( aField[2] )
         ENDIF
      ENDIF
   NEXT

// split program name for two reason
// 1. to have the current path
// 2. to have the program name and register default ProgramName resource file
   hb_fnamesplit( hb_progname(), @cPath, @cFile, @cExt )

// if QtPluginPath not evalueted create <exePath\Qt\plugins>
   IF VALTYPE( QtPluginPath ) <> "C"
      QtPluginPath := cPath + "Qt" + hb_ps() + "plugins"
   ENDIF

   ::s_qStarted   := .T.
   ::s_qLocale    := QLocale()
   ::s_qLocale:setDefault( QLocale():system() )  // retrieve system by default
   ::s_qApp       := QApplication()
   ::s_qRes       := QResource()

   ::s_qApp:addLibraryPath( QtPluginPath )
   ::oQtObject   := ::s_qApp:DeskTop()

   Self:RegisterResource( cFile )

RETURN Self

/*..............................................................................
 Reset
..............................................................................*/
METHOD HMGQT:Reset()

   Self:Quit()
   
   Self:s_qApp          := NIL
   Self:s_qRes          := NIL
   Self:s_aResources    := {}
   Self:s_qLocale       := NIL
   Self:s_qStarted      := .F.

   Self:oDefaultParent  := NIL
   Self:nObjectCounter  := 0
   Self:oMainWindow     := NIL
   Self:lGridCellFlag   := .F.

RETURN Self

/*..............................................................................
 RegisterResource
..............................................................................*/
METHOD HMGQT:RegisterResource( cResource )

   LOCAL cResFileName := "HBQTRES_" + ALLTRIM( cResource ) + "()"

   IF TYPE( cResFileName ) == "UI"
      IF ::s_qRes:registerResource_1( &cResFileName ) == .T.
         AADD( ::s_aResources, cResFileName )
      ENDIF
   ENDIF

RETURN Self

/*..............................................................................
 UnRegisterResources
..............................................................................*/
METHOD HMGQT:UnRegisterResources()

   LOCAL nI, cResFileName

   FOR nI := 1 TO LEN( ::s_aResources )
      cResFileName := ::s_aResources[nI]
      ::s_qRes:unregisterResource_1( &cResFileName )
   NEXT nI

   ASIZE( ::s_aResources, 0 )

RETURN Self

/*..............................................................................
 SetLocale
..............................................................................*/
METHOD HMGQT:SetLocale( nLanguage, nCountry )

   IF ( PCOUNT() == 2 .OR. PCOUNT() == 1 ) .AND. VALTYPE( nLanguage ) == "N"
      IF PCOUNT() == 2 .AND. VALTYPE( nCountry ) == "N"
         ::oQtLocale:setDefault( QLocale( nLanguage, nCountry ) )
      ELSEIF PCOUNT() == 1
         ::oQtLocale:setDefault( QLocale( nLanguage ) )
      ENDIF
   ENDIF

RETURN Self

/*..............................................................................
 Language
..............................................................................*/
METHOD HMGQT:Language()
RETURN ::oQtLocale:Language()

/*..............................................................................
 Country
..............................................................................*/
METHOD HMGQT:Country()
RETURN ::oQtLocale:Country()

